@@ -19,8 +19,8 @@ class TestStandardLibraryRenames(CodeHandler):
 
     def setUp(self):
         self.interpreter = 'python'
-        self.tempdir = tempfile.mkdtemp() + os.path.sep
         standard_library.install_hooks()
+        super(TestStandardLibraryRenames, self).setUp()
 
     @unittest.skipIf(utils.PY3, 'generic import tests are for Py2 only')
     def test_all(self):
@@ -84,12 +84,17 @@ class TestStandardLibraryRenames(CodeHandler):
             self.assertTrue(example_PY2_check)
         else:
             self.assertFalse(example_PY2_check)
-        standard_library.enable_hooks()
-        # The import should succeed again now:
-        import builtins
-        self.assertTrue(len(old_meta_path) == len(sys.meta_path))
 
-    def test_remove_hooks(self):
+        standard_library.install_hooks()
+
+        # Imports should succeed again now:
+        import builtins
+        import configparser
+        if utils.PY2:
+            self.assertTrue(standard_library.detect_hooks())
+            self.assertTrue(len(old_meta_path) == len(sys.meta_path))
+
+    def test_remove_hooks2(self):
         """
         As above, but with the new names
         """
@@ -118,6 +123,22 @@ class TestStandardLibraryRenames(CodeHandler):
         import builtins
         self.assertTrue(len(old_meta_path) == len(sys.meta_path))
 
+    def test_detect_hooks(self):
+        """
+        Tests whether the future.standard_library.detect_hooks is doing
+        its job.
+        """
+        standard_library.install_hooks()
+        if utils.PY2:
+            self.assertTrue(standard_library.detect_hooks())
+
+        meta_path = copy.copy(sys.meta_path)
+
+        standard_library.remove_hooks()
+        if utils.PY2:
+            self.assertEqual(len(meta_path), len(sys.meta_path) + 1)
+            self.assertFalse(standard_library.detect_hooks())
+
     @unittest.skipIf(utils.PY3, 'not testing for old urllib on Py3')
     def test_old_urllib_import(self):
         """
@@ -158,7 +179,6 @@ class TestStandardLibraryRenames(CodeHandler):
         Tests whether sys.maxsize is available.
         """
         from sys import maxsize
-        print(maxsize)
         self.assertTrue(maxsize > 0)
 
     def test_itertools_filterfalse(self):
@@ -312,6 +332,40 @@ class TestStandardLibraryRenames(CodeHandler):
         imp.reload(imp)
         self.assertTrue(True)
 
+
+try:
+    import requests
+except ImportError:
+    requests = None
+
+class TestRequests(CodeHandler):
+    """
+    This class tests whether the requests module conflicts with the
+    standard library import hooks, as in issue #19.
+    """
+    @unittest.expectedFailure
+    @unittest.skipIf(requests is None, 'Install ``requests`` if you would like' \
+                     + ' to test ``requests`` + future compatibility (issue #19)')
+    def test_requests(self):
+        with open(self.tempdir + 'test_imports_future_stdlib.py', 'w') as f:
+            f.write('from future import standard_library')
+        # print('sys.meta_path is: ', sys.meta_path)
+        sys.path.insert(0, self.tempdir)
+        print('Importing test_imports_future_stdlib ...')
+        try:
+            import test_imports_future_stdlib
+            standard_library.remove_hooks()
+            import requests
+            r = requests.get('http://google.com')
+            self.assertTrue(True)
+        except Exception as e:
+            raise e
+        else:
+            print('Succeeded!')
+        finally:
+            sys.path.remove(self.tempdir)
+
+
 if __name__ == '__main__':
     unittest.main()
     standard_library.remove_hooks()
